MethodChannelPaytmpaymentsAllinonesdk class

An implementation of PaytmpaymentsAllinonesdkPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTransaction(String mid, String orderId, String amount, String txnToken, String callbackUrl, bool isStaging, bool restrictAppInvoke, [bool enableAssist = true]) Future<Map?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited