PaytmpaymentsAllinonesdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • PaytmpaymentsAllinonesdkPlatform
Implementers

Constructors

PaytmpaymentsAllinonesdkPlatform()
Constructs a PaytmpaymentsAllinonesdkPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTransaction(String mid, String orderId, String amount, String txnToken, String callbackUrl, bool isStaging, bool restrictAppInvoke, [bool enableAssist = true]) Future<Map?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PaytmpaymentsAllinonesdkPlatform
The default instance of PaytmpaymentsAllinonesdkPlatform to use.
getter/setter pair